import { PetClassInfo } from '../../types/Pet';

interface ConfirmationModalProps {
  selectedClass: { key: string; info: PetClassInfo };
  handleConfirm: () => void;
  setShowConfirmation: (show: boolean) => void;
  setSelectedClass: (selected: { key: string; info: PetClassInfo } | null) => void;
}

export default function ConfirmationModal({
  selectedClass,
  handleConfirm,
  setShowConfirmation,
  setSelectedClass,
}: ConfirmationModalProps) {
  return (
    <div className="fixed inset-0 bg-black/50 flex items-center justify-center p-4">
      <div className="bg-gray-800 p-6 rounded-xl max-w-md w-full">
        <h2 className="text-2xl font-bold mb-4">Confirm Selection</h2>
        <p className="mb-4">Are you sure you want to choose {selectedClass.info.name}?</p>
        <div className="space-y-2 mb-6">
          {selectedClass.info.modifiers.map((modifier, index) => (
            <div key={index} className="text-sm text-gray-300">• {modifier}</div>
          ))}
        </div>
        <div className="flex space-x-4">
          <button
            onClick={handleConfirm}
            className="flex-1 bg-blue-600 hover:bg-blue-700 px-4 py-2 rounded"
          >
            Confirm
          </button>
          <button
            onClick={() => {
              setShowConfirmation(false);
              setSelectedClass(null);
            }}
            className="flex-1 bg-gray-600 hover:bg-gray-700 px-4 py-2 rounded"
          >
            Cancel
          </button>
        </div>
      </div>
    </div>
  );
}
