import { PetClassInfo } from '../../types/Pet';

interface NameModalProps {
  selectedClass: { key: string; info: PetClassInfo };
  petName: string;
  setPetName: (name: string) => void;
  handleNameSubmit: () => void;
  setShowNameModal: (show: boolean) => void;
  setSelectedClass: (selected: { key: string; info: PetClassInfo } | null) => void;
}

export default function NameModal({
  selectedClass,
  petName,
  setPetName,
  handleNameSubmit,
  setShowNameModal,
  setSelectedClass,
}: NameModalProps) {
  return (
    <div className="fixed inset-0 bg-black/50 backdrop-blur-sm flex items-center justify-center p-4">
      <div className="bg-gray-800 p-6 rounded-xl max-w-md w-full">
        <h2 className="text-2xl font-bold mb-2">Name Your Pet</h2>
        <p className="text-gray-400 mb-6">
          Creating a new {selectedClass.info.name.toLowerCase()} pet
        </p>
        <div className="space-y-4">
          <div>
            <label htmlFor="petName" className="block text-sm font-medium text-gray-300 mb-2">
              Pet Name
            </label>
            <input
              type="text"
              id="petName"
              value={petName}
              onChange={(e) => setPetName(e.target.value)}
              className="w-full px-4 py-2 bg-gray-700 border border-gray-600 rounded-lg focus:ring-2 focus:ring-blue-500 focus:border-transparent"
              placeholder="Enter a name for your pet"
              autoFocus
            />
          </div>
          <div className="flex space-x-4">
            <button
              onClick={handleNameSubmit}
              disabled={!petName.trim()}
              className={`flex-1 px-4 py-2 rounded-lg ${
                petName.trim()
                  ? 'bg-blue-600 hover:bg-blue-700'
                  : 'bg-blue-600/50 cursor-not-allowed'
              }`}
            >
              Create Pet
            </button>
            <button
              onClick={() => {
                setShowNameModal(false);
                setSelectedClass(null);
              }}
              className="flex-1 px-4 py-2 bg-gray-600 hover:bg-gray-700 rounded-lg"
            >
              Cancel
            </button>
          </div>
        </div>
      </div>
    </div>
  );
}
