import { AxiosInstance } from 'axios';
import { ApiError } from './types';

export function setupInterceptors(axiosInstance: AxiosInstance) {
  // Request interceptor
  axiosInstance.interceptors.request.use(
    (config) => {
      // Get token from storage
      const token = localStorage.getItem('auth_token');
      
      // Add authorization header if token exists
      if (token) {
        config.headers.Authorization = `Bearer ${token}`;
      }

      // Log request (development only)
      if (import.meta.env.DEV) {
        console.log(`🚀 [API] ${config.method?.toUpperCase()} ${config.url}`, {
          data: config.data,
          params: config.params,
        });
      }

      return config;
    },
    (error) => {
      // Log request error (development only)
      if (import.meta.env.DEV) {
        console.error('❌ [API] Request Error:', error);
      }
      return Promise.reject(error);
    }
  );

  // Response interceptor
  axiosInstance.interceptors.response.use(
    (response) => {
      // Log response (development only)
      if (import.meta.env.DEV) {
        console.log(`✅ [API] Response:`, {
          status: response.status,
          data: response.data,
        });
      }

      return response;
    },
    (error) => {
      // Log response error (development only)
      if (import.meta.env.DEV) {
        console.error('❌ [API] Response Error:', error.response || error);
      }

      // Handle authentication errors
      if (error.response?.status === 401) {
        // Clear token and redirect to login
        localStorage.removeItem('auth_token');
        window.location.href = '/login';
      }

      return Promise.reject(error);
    }
  );

  return axiosInstance;
}